aboutsummaryrefslogtreecommitdiff
path: root/obj_commit.go
diff options
context:
space:
mode:
Diffstat (limited to 'obj_commit.go')
-rw-r--r--obj_commit.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/obj_commit.go b/obj_commit.go
index 4a5d2567..8abb363f 100644
--- a/obj_commit.go
+++ b/obj_commit.go
@@ -17,8 +17,8 @@ type Commit struct {
ExtraHeaders []ExtraHeader
}
-// ObjType allows Commit to satisfy the Object interface.
-func (*Commit) ObjType() ObjType {
+// ObjectType allows Commit to satisfy the Object interface.
+func (*Commit) ObjectType() ObjectType {
return ObjCommit
}